@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 import re
-from typing import List, Union, Iterable, Any, Dict, Literal, Tuple
+from typing import Iterable, Any, Literal, TypeVar, Dict, Union
 
 from .config import lang
 from .core import BasePattern, PatternModel
@@ -7,23 +9,35 @@ from .exception import MatchFailed
 from .util import Empty
 
 
-class UnionArg(BasePattern):
+class RegexPattern(BasePattern[Union[dict, tuple]]):
+    """针对正则的特化匹配，支持正则组"""
+
+    def __init__(self, pattern: str, alias: str | None = None):
+        super().__init__(pattern, origin=Union[dict, tuple], alias=alias or 'regex[:group]')
+
+    def match(self, input_: str | Any):
+        if not isinstance(input_, str):
+            raise MatchFailed(lang.type_error.format(target=input_))
+        if mat := self.regex_pattern.match(input_):
+            return mat.groupdict() or mat.groups()
+        raise MatchFailed(lang.content_error.format(target=input_))
+
+
+class UnionPattern(BasePattern):
     """多类型参数的匹配"""
 
     optional: bool
-    arg_value: List[Union[BasePattern, object, str]]
-    for_validate: List[BasePattern]
-    for_equal: List[Union[str, object]]
+    base: list[BasePattern | object | str]
+    for_validate: list[BasePattern]
+    for_equal: list[str | object]
 
-    def __init__(
-        self, base: Iterable[Union[BasePattern, object, str]], anti: bool = False
-    ):
-        self.arg_value = list(base)
+    def __init__(self, base: Iterable[BasePattern | object | str], anti: bool = False):
+        self.base = list(base)
         self.optional = False
         self.for_validate = []
         self.for_equal = []
 
-        for arg in self.arg_value:
+        for arg in self.base:
             if arg == Empty:
                 self.optional = True
                 self.for_equal.append(None)
@@ -38,7 +52,7 @@ class UnionArg(BasePattern):
             r"(.+?)", PatternModel.KEEP, str, alias=alias_content, anti=anti
         )
 
-    def match(self, text: Union[str, Any]):
+    def match(self, text: str | Any):
         if not text:
             text = None
         if text not in self.for_equal:
@@ -53,10 +67,10 @@ class UnionArg(BasePattern):
             "|".join(repr(a) for a in (*self.for_validate, *self.for_equal))
         )
 
-    def prefixed(self) -> "UnionArg":
+    def prefixed(self) -> UnionPattern:
         from .main import type_parser
 
-        return UnionArg(
+        return UnionPattern(
             [pat.prefixed() for pat in self.for_validate]
             + [
                 type_parser(eq).prefixed() if isinstance(eq, str) else eq
@@ -65,10 +79,10 @@ class UnionArg(BasePattern):
             self.anti,
         )
 
-    def suffixed(self) -> "UnionArg":
+    def suffixed(self) -> UnionPattern:
         from .main import type_parser
 
-        return UnionArg(
+        return UnionPattern(
             [pat.suffixed() for pat in self.for_validate]
             + [
                 type_parser(eq).suffixed() if isinstance(eq, str) else eq
@@ -78,46 +92,45 @@ class UnionArg(BasePattern):
         )
 
 
-class SequenceArg(BasePattern):
+TSeq = TypeVar("TSeq", list, tuple, set)
+
+
+class SequencePattern(BasePattern[TSeq]):
     """匹配列表或者元组或者集合"""
 
-    form: str
-    arg_value: BasePattern
+    base: BasePattern
     _mode: Literal["pre", "suf", "all"]
 
-    def __init__(self, base: BasePattern, form: str = "list"):
-        self.form = form
-        self.arg_value = base
+    def __init__(self, form: type[TSeq], base: BasePattern):
+        self.base = base
         self._mode = "all"
-        if form == "list":
+        if form is list:
             super().__init__(
-                r"\[(.+?)\]", PatternModel.REGEX_MATCH, list, alias=f"list[{base}]"
+                r"\[(.+?)\]", PatternModel.REGEX_MATCH, form, alias=f"list[{base}]"
             )
-        elif form == "tuple":
+        elif form is tuple:
             super().__init__(
-                r"\((.+?)\)", PatternModel.REGEX_MATCH, tuple, alias=f"tuple[{base}]"
+                r"\((.+?)\)", PatternModel.REGEX_MATCH, form, alias=f"tuple[{base}]"
             )
-        elif form == "set":
+        elif form is set:
             super().__init__(
-                r"\{(.+?)\}", PatternModel.REGEX_MATCH, set, alias=f"set[{base}]"
+                r"\{(.+?)\}", PatternModel.REGEX_MATCH, form, alias=f"set[{base}]"
             )
         else:
-            raise ValueError(lang.sequence_form_error.format(target=form))
+            raise ValueError(lang.sequence_form_error.format(target=str(form)))
 
-    def match(self, text: Union[str, Any]):
+    def match(self, text: str | Any):
         _res = super().match(text)
         _max = 0
-        success: List[Tuple[int, Any]] = []
-        fail: List[Tuple[int, MatchFailed]] = []
+        success: list[tuple[int, Any]] = []
+        fail: list[tuple[int, MatchFailed]] = []
         for _max, s in enumerate(
             re.split(r"\s*,\s*", _res) if isinstance(_res, str) else _res
         ):
             try:
-                success.append((_max, self.arg_value.match(s)))
+                success.append((_max, self.base.match(s)))
             except MatchFailed:
-                fail.append(
-                    (_max, MatchFailed(f"{s} is not matched with {self.arg_value}"))
-                )
+                fail.append((_max, MatchFailed(f"{s} is not matched with {self.base}")))
 
         if (
             (self._mode == "all" and fail)
@@ -132,42 +145,46 @@ class SequenceArg(BasePattern):
         return self.origin(i[1] for i in success)
 
     def __repr__(self):
-        return f"{self.form}[{self.arg_value}]"
+        return f"{self.origin.__name__}[{self.base}]"
 
-    def prefixed(self):
+    def prefixed(self) -> SequencePattern:
         self._mode = "pre"
-        return super(SequenceArg, self).prefixed()
+        return super(SequencePattern, self).prefixed()
 
-    def suffixed(self):
+    def suffixed(self) -> SequencePattern:
         self._mode = "suf"
-        return super(SequenceArg, self).suffixed()
+        return super(SequencePattern, self).suffixed()
 
 
-class MappingArg(BasePattern):
+TKey = TypeVar("TKey")
+TVal = TypeVar("TVal")
+
+
+class MappingPattern(BasePattern[Dict[TKey, TVal]]):
     """匹配字典或者映射表"""
 
-    arg_key: BasePattern
-    arg_value: BasePattern
+    key: BasePattern[TKey]
+    value: BasePattern[TVal]
     _mode: Literal["pre", "suf", "all"]
 
-    def __init__(self, arg_key: BasePattern, arg_value: BasePattern):
-        self.arg_key = arg_key
-        self.arg_value = arg_value
+    def __init__(self, arg_key: BasePattern[TKey], arg_value: BasePattern[TVal]):
+        self.key = arg_key
+        self.value = arg_value
         self._mode = "all"
         super().__init__(
             r"\{(.+?)\}",
             PatternModel.REGEX_MATCH,
             dict,
-            alias=f"dict[{self.arg_key}, {self.arg_value}]",
+            alias=f"dict[{self.key}, {self.value}]",
         )
 
-    def match(self, text: Union[str, Any]):
+    def match(self, text: str | Any):
         _res = super().match(text)
-        success: List[Tuple[int, Any, Any]] = []
-        fail: List[Tuple[int, MatchFailed]] = []
+        success: list[tuple[int, Any, Any]] = []
+        fail: list[tuple[int, MatchFailed]] = []
         _max = 0
 
-        def _generator_items(res: Union[str, Dict]):
+        def _generator_items(res: str | dict):
             if isinstance(res, dict):
                 yield from res.items()
                 return
@@ -177,9 +194,16 @@ class MappingArg(BasePattern):
         for _max, item in enumerate(_generator_items(_res)):
             k, v = item
             try:
-                success.append((_max, self.arg_key.match(k), self.arg_value.match(v)))
+                success.append((_max, self.key.match(k), self.value.match(v)))
             except MatchFailed:
-                fail.append((_max, MatchFailed(f"{k}: {v} is not matched with {self.arg_key}: {self.arg_value}")))
+                fail.append(
+                    (
+                        _max,
+                        MatchFailed(
+                            f"{k}: {v} is not matched with {self.key}: {self.value}"
+                        ),
+                    )
+                )
         if (
             (self._mode == "all" and fail)
             or (self._mode == "pre" and fail and fail[0][0] == 0)
@@ -193,15 +217,15 @@ class MappingArg(BasePattern):
         return {i[1]: i[2] for i in success}
 
     def __repr__(self):
-        return f"dict[{self.arg_key.origin.__name__}, {self.arg_value}]"
+        return f"dict[{self.key.origin.__name__}, {self.value}]"
 
-    def prefixed(self):
+    def prefixed(self) -> MappingPattern:
         self._mode = "pre"
-        return super(MappingArg, self).prefixed()
+        return super(MappingPattern, self).prefixed()
 
-    def suffixed(self):
+    def suffixed(self) -> MappingPattern:
         self._mode = "suf"
-        return super(MappingArg, self).suffixed()
+        return super(MappingPattern, self).suffixed()
 
 
-__all__ = ["UnionArg", "SequenceArg", "MappingArg"]
+__all__ = ["RegexPattern", "UnionPattern", "SequencePattern", "MappingPattern"]
